@@ -16,7 +16,9 @@ import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-redshift", "1.49.0", __name__[0:-6], "aws-redshift@1.49.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-redshift", "1.61.1", __name__[0:-6], "aws-redshift@1.61.1.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
